/*
 * @(#)ezLicStatusCodes.h    1.00   02/21/02
 *
 * Copyright (c) 2002-2006 Agilis Software LLC, Santa Clara, CA, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Agilis Software LLC ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only
 * in accordance with the terms of the license agreement you entered
 * into with Agilis Software LLC.
 */

/*
 * Defines error and warning status codes returned by EasyLicenser API calls.
 * A successful execution of an API call returns a status code of 0.
 * An execution that results in a success with warnings returns a
 * positive status code that represents a bitmap of the EZLIC_WARN_* 
 * warning codes defined in this file.  An execution that results in an 
 * error returns a negative status code which is to be interpreted according 
 * to the EZLIC_EXC_* codes defined in this file.
 */

#ifndef __EZLICSTATUSCODES_H
#define __EZLICSTATUSCODES_H

/* The success-with-no-strings-attached return code */
#define		EZLIC_EXC_NO_EXCEPTION 0


/**
* Base exception code (invalid)
*/
#define     EZLIC_EXC_BASE  -1
/**
* Malformed license key or key cookie
*/
#define     EZLIC_EXC_MALFORMED_KEY  -2
/**
* Expired license key
*/
#define     EZLIC_EXC_EXPIRED  -3
/**
* Exceeded license quota
*/
#define     EZLIC_EXC_EXCEEDED_LIMITS  -4
/**
* Invalid host or user name
*/
#define     EZLIC_EXC_INVALID_HOST_USER_NET  -5
/**
* Invalid custom key
*/
#define     EZLIC_EXC_INVALID_CUSTOM_KEY  -6
/**
* Unimplemented feature
*/
#define     EZLIC_EXC_UNIMPLEMENTED  -7
/**
* Key generation error condition (should never happen)
*/
#define     EZLIC_EXC_GEN  -8
/**
* Vendor key parse error condition (should never happen)
*/
#define     EZLIC_EXC_VENDOR  -9
/**
* Internal error condition
*/
#define     EZLIC_EXC_INTERNAL  -10
/**
* OS error
*/
#define     EZLIC_EXC_OS  -11
/**
* EasyLicenser configuration error
*/
#define     EZLIC_EXC_CONFIG  -12
/**
* Unlicensed option (a usage error)
*/
#define     EZLIC_EXC_UNLICENSED_OPTION  -13
/**
* General usage error (eg. bad parameter)
*/
#define     EZLIC_EXC_USAGE  -14
/**
* Authentication error (product name / application password)
*/
#define     EZLIC_EXC_AUTHENT  -15

/**
* License is already active
*/
#define     EZLIC_EXC_LIC_ALREADY_ACTIVE  -16

/**
* License is not active
*/
#define     EZLIC_EXC_LIC_INACTIVE  -17

/**
* License key is not intended for perpetual use
*/
#define     EZLIC_EXC_PERPETUAL_USE  -18

/**
* Invalid auxiliary key.
*/
#define     EZLIC_EXC_INVALID_AUXKEY  -19

/**
* Tempered system clock
*/
#define     EZLIC_EXC_TAMPERED_CLOCK  -20

/**
* Key installed too late
*/
#define     EZLIC_EXC_INSTALLED_LATE  -21


/**
 * Warning codes.  When an API call returns a positive status code,
 * the value is a bitmap of the following bits.
 */
/**
* Expiration date approaching
*/
#define     EZLIC_WARN_EXPIRING  1
/**
* Reaching quota limit
*/
#define     EZLIC_WARN_QUOTA  2
/**
* Gone past expiration date and in grace period
*/
#define     EZLIC_WARN_EXPIRED  4
/**
* Exceeded quota limit and in grace quota
*/
#define     EZLIC_WARN_QUOTA_EXCEEDED  8
/**
 * Excessive quota grace specified - truncated to 5 / 25 pct of quota
 */
#define		EZLIC_WARN_QUOTA_GRACE_TRUNC 16
/**
 * Excessive expiration grace specified - truncated to 5 / 25 pct of balance days
 */
#define		EZLIC_WARN_EXP_GRACE_TRUNC 32


#endif


